@@ -5,7 +5,7 @@ $self = {
                       'Cairo',
                       'Glib'
                     ],
-          'inc' => '-I/usr/include/cairo -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/pixman-1 -I/usr/include/freetype2 -I/usr/include/libpng16 -I/usr/include/harfbuzz -I/usr/include/uuid ',
+          'inc' => '-I/usr/include/cairo -I/usr/include/lzo -I/usr/include/libpng16 -I/usr/include/freetype2 -I/usr/include/harfbuzz -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/pixman-1 ',
           'libs' => '-lcairo-gobject -lcairo -lgobject-2.0 -lglib-2.0 ',
           'typemaps' => []
         };
@@ -27,11 +27,6 @@ $inc = $self->{inc};
 
 	sub Inline {
 		my ($class, $lang) = @_;
-		if ($lang ne 'C') {
-			warn "Warning: Inline hints not available for $lang language
-";
-			return;
-		}
 		+{ map { (uc($_) => $self->{$_}) } qw(inc libs typemaps) };
 	}
 
